pub fn _mm256_mask_add_ph(
src: __m256h,
k: u16,
a: __m256h,
b: __m256h,
) -> __m256hExpand description
Add packed half-precision (16-bit) floating-point elements in a and b, and store the results in dst using writemask k (elements are copied from src when the corresponding mask bit is not set).