pub fn _mm256_mask_cvtepu32_ph(src: __m128h, k: u8, a: __m256i) -> __m128hExpand description
Convert packed unsigned 32-bit integers in a to packed half-precision (16-bit) floating-point elements, and store the results in dst using writemask k (elements are copied from src to dst when the corresponding mask bit is not set).