_mm256_mask_cvtph_epi64

Function _mm256_mask_cvtph_epi64 

1.94.0 · Source
pub fn _mm256_mask_cvtph_epi64(src: __m256i, k: u8, a: __m128h) -> __m256i
Convert packed half-precision (16-bit) floating-point elements in a to packed 64-bit integers, and store the results in dst using writemask k (elements are copied from src when the corresponding mask bit is not set).

Intel’s documentation