_mm256_mask_cvtph_epu16

Function _mm256_mask_cvtph_epu16 

1.94.0 · Source
pub fn _mm256_mask_cvtph_epu16(src: __m256i, k: u16, a: __m256h) -> __m256i
Convert packed half-precision (16-bit) floating-point elements in a to packed unsigned 16-bit integers, and store the results in dst using writemask k (elements are copied from src when the corresponding mask bit is not set).

Intel’s documentation