pub fn _mm256_mask_rcp_ph(src: __m256h, k: u16, a: __m256h) -> __m256hExpand description
Compute the approximate reciprocal of packed 16-bit floating-point elements in a and stores the results in dst
using writemask k (elements are copied from src when the corresponding mask bit is not set).
The maximum relative error for this approximation is less than 1.5*2^-12.