pub fn _mm256_mask_sqrt_ph(src: __m256h, k: u16, a: __m256h) -> __m256hExpand description
Compute the square root of packed half-precision (16-bit) floating-point elements in a, and store the results in dst using writemask k (elements are copied from src when the corresponding mask bit is not set).