_mm256_maskz_cvtepi32_pd

Function _mm256_maskz_cvtepi32_pd 

1.89.0 (const: unstable) · Source
pub fn _mm256_maskz_cvtepi32_pd(k: u8, a: __m128i) -> __m256d
Convert packed signed 32-bit integers in a to packed double-precision (64-bit) floating-point elements, and store the results in dst using zeromask k (elements are zeroed out when the corresponding mask bit is not set).

Intel’s documentation