_mm256_maskz_cvttph_epi32

Function _mm256_maskz_cvttph_epi32 

1.94.0 · Source
pub fn _mm256_maskz_cvttph_epi32(k: u8, a: __m128h) -> __m256i
Convert packed half-precision (16-bit) floating-point elements in a to packed 32-bit integers with truncation, and store the results in dst using zeromask k (elements are zeroed out when the corresponding mask bit is not set).

Intel’s documentation