pub fn _mm512_mask_cvtepu32_ph(src: __m256h, k: u16, a: __m512i) -> __m256hExpand description
Convert packed unsigned 32-bit integers in a to packed half-precision (16-bit) floating-point elements, and store the results in dst using writemask k (elements are copied from src to dst when the corresponding mask bit is not set).