pub fn _mm512_maskz_cvtepu64_ph(k: u8, a: __m512i) -> __m128hExpand description
Convert packed unsigned 64-bit integers in a to packed half-precision (16-bit) floating-point elements, and store the results in dst using zeromask k (elements are zeroed out when the corresponding mask bit is not set).