pub fn _mm512_maskz_mul_ph(k: u32, a: __m512h, b: __m512h) -> __m512hExpand description
Multiply packed half-precision (16-bit) floating-point elements in a and b, and store the results in dst using zeromask k (elements are zeroed out when the corresponding mask bit is not set).