_mm512_sqrt_round_ph

Function _mm512_sqrt_round_ph 

1.94.0 · Source
pub fn _mm512_sqrt_round_ph<const ROUNDING: i32>(a: __m512h) -> __m512h
Compute the square root of packed half-precision (16-bit) floating-point elements in a, and store the results in dst. Rounding is done according to the rounding parameter, which can be one of:

Intel’s documentation