_mm_mask_add_ph

Function _mm_mask_add_ph 

1.94.0 (const: unstable) · Source
pub fn _mm_mask_add_ph(src: __m128h, k: u8, a: __m128h, b: __m128h) -> __m128h
Add packed half-precision (16-bit) floating-point elements in a and b, and store the results in dst using writemask k (elements are copied from src when the corresponding mask bit is not set).

Intel’s documentation