_mm_maskz_cvtph_epu32

Function _mm_maskz_cvtph_epu32 

1.94.0 · Source
pub fn _mm_maskz_cvtph_epu32(k: u8, a: __m128h) -> __m128i
Convert packed half-precision (16-bit) floating-point elements in a to packed 32-bit unsigned integers, and store the results in dst using zeromask k (elements are zeroed out when the corresponding mask bit is not set).

Intel’s documentation