pub fn _mm_maskz_fmsub_ph(k: u8, a: __m128h, b: __m128h, c: __m128h) -> __m128hExpand description
Multiply packed half-precision (16-bit) floating-point elements in a and b, subtract packed elements in c from the intermediate result, and store the results in dst using zeromask k (the element is zeroed out when the corresponding mask bit is not set).